Rebrand to flashprog and update URLs

Mostly automated `sed` work. As of now, URLs to the old wiki are broken
either way, so changing them shouldn't hurt. Other URLs (e.g. to mailing
list archives) were hopefully filtered correctly.

Change-Id: I9d43bfd0e675eff2fcbad05f304b9ce9f5006b08
Signed-off-by: Nico Huber <nico.h@gmx.de>
Reviewed-on: https://review.sourcearcade.org/c/flashrom-stable/+/21
diff --git a/buspirate_spi.c b/buspirate_spi.c
index 2909a3e..27bca8a 100644
--- a/buspirate_spi.c
+++ b/buspirate_spi.c
@@ -245,7 +245,7 @@
 		dev = NULL;
 	}
 	if (!dev) {
-		msg_perr("No serial device given. Use flashrom -p buspirate_spi:dev=/dev/ttyUSB0\n");
+		msg_perr("No serial device given. Use flashprog -p buspirate_spi:dev=/dev/ttyUSB0\n");
 		return 1;
 	}
 
@@ -326,7 +326,7 @@
 	bp_data->commbufsize = bp_commbufsize;
 
 	/* This is the brute force version, but it should work.
 	 * It is likely to fail if a previous flashrom run was aborted during a write with the new SPI commands
 	 * in firmware v5.5 because that firmware may wait for up to 4096 bytes of input before responding to
 	 * 0x00 again. The obvious workaround (sending 4096 bytes of \0) may cause significant startup delays.
 	 */
@@ -326,7 +326,7 @@
 
 	/* This is the brute force version, but it should work.
-	 * It is likely to fail if a previous flashrom run was aborted during a write with the new SPI commands
+	 * It is likely to fail if a previous flashprog run was aborted during a write with the new SPI commands
 	 * in firmware v5.5 because that firmware may wait for up to 4096 bytes of input before responding to
 	 * 0x00 again. The obvious workaround (sending 4096 bytes of \0) may cause significant startup delays.